@@ -1,6 +1,6 @@
 package XML::MyXML;
 # ABSTRACT: A simple-to-use XML module, for parsing and creating XML documents
-$XML::MyXML::VERSION = '0.9007';
+$XML::MyXML::VERSION = '0.9008';
 use strict;
 use warnings;
 use Carp;
@@ -164,8 +164,7 @@ sub xml_to_object {
 		} elsif ($el =~ /^<[^>]+\/>$/) {
 			my ($element) = $el =~ /^<([^\s>\/]+)/g;
 			if (! length($element)) { croak encode_utf8("Error: Strange element: '$el'"); }
-			my $elementmeta = quotemeta($element);
-			$el =~ s/^<$elementmeta//;
+			$el =~ s/^<\Q$element\E//;
 			$el =~ s/\/>$//;
 			my @attrs = $el =~ /\s+(\S+=(['"]).*?\2)/g;
 			my $i = 1;
@@ -183,8 +182,7 @@ sub xml_to_object {
 		} elsif ($el =~ /^<[^\s>\/][^>]*>$/) {
 			my ($element) = $el =~ /^<([^\s>]+)/g;
 			if (! length($element)) { croak encode_utf8("Error: Strange element: '$el'"); }
-			my $elementmeta = quotemeta($element);
-			$el =~ s/^<$elementmeta//;
+			$el =~ s/^<\Q$element\E//;
 			$el =~ s/>$//;
 			my @attrs = $el =~ /\s+(\S+=(['"]).*?\2)/g;
 			my $i = 1;
@@ -476,7 +474,7 @@ sub check_xml {
 
 
 package XML::MyXML::Object;
-$XML::MyXML::Object::VERSION = '0.9007';
+$XML::MyXML::Object::VERSION = '0.9008';
 use Carp;
 use Encode;
 
@@ -697,7 +695,7 @@ XML::MyXML - A simple-to-use XML module, for parsing and creating XML documents
 
 =head1 VERSION
 
-version 0.9007
+version 0.9008
 
 =head1 SYNOPSIS
 
